######################################################################
#      S H O P D O C _ H E A D E R . T C L
######################################################################
# EVENT HANDLER SECTION
#   This section contains the control section for creating an operation list
#
#   CAM will loop thru each event in the path and call the procedure
#   whose name is the name of the event.
#
# 
#

#####################################################################
# Source the empty handlers for Shop doc
#===================================================================
set mom_source_directory [MOM_ask_env_var UGII_CAM_SHOP_DOC_DIR]
source "$mom_source_directory/pusty.tcl"
#===================================================================


#==============================================================================
proc ShopDoc_Header_text { } {
#==============================================================================
  MOM_output_literal " "
  MOM_output_literal "                          DOKUMENTACJA TECHNOLOGICZNA"
  MOM_output_literal "                          **** ***** *************"
}

#==============================================================================
proc Setup_Header_text { } {
#==============================================================================
  global mom_part_name
  global mom_logname
  global mom_date

  set part_split [split $mom_part_name /]
  set length [llength $part_split]
  set part_name [lindex $part_split [expr $length - 1]]

  MOM_output_literal "--------------------------------------------------------------------------------"
  set output [format "STWORZONE PRZEZ : %-25s  DATA : %-20s" \
                                     $mom_logname $mom_date]
  MOM_output_literal "$output"
  set output [format "NAZWA CZʌCI : %-25s" $mom_part_name]
  MOM_output_literal "$output"
  MOM_output_literal "--------------------------------------------------------------------------------"
}

#==============================================================================
proc ShopDoc_Header_html { } {
#==============================================================================
  global image_dir
  set image_dir [MOM_ask_env_var UGII_CAM_SHOP_DOC_DIR]
  regsub -all {[ ]} $image_dir "%20" image_dir

  MOM_output_literal "<HTML>"
  MOM_output_literal "<HEAD>"
  MOM_output_literal "<TITLE> DOKUMENTACJA TECHNOLOGICZNA </TITLE>"
  MOM_output_literal "</HEAD>"
  MOM_output_literal "<H1 ALIGN=CENTER><IMG SRC=\
       file:///$image_dir///cam_ug.gif >&nbsp;</IMG></H1>"
  MOM_output_literal "<H1 ALIGN=CENTER><B> DOKUMENTACJA TECHNOLOGICZNA </B><H1>"
}

#==============================================================================
proc Setup_Header_html { } {
#==============================================================================
  global mom_part_name
  global mom_logname
  global mom_date

  set part_split [split $mom_part_name /]
  set length [llength $part_split]
  set part_name [lindex $part_split [expr $length - 1]]

  MOM_output_literal "<BR>"
  MOM_output_literal "<CENTER><table WIDTH=700 BORDER=0>"
  MOM_output_literal "<tr ALIGN=CENTER VALIGN=CENTER>"
  MOM_output_literal "<th ALIGN=LEFT> WYGENEROWA : $mom_logname</th>"
  MOM_output_literal "<th ALIGN=CENTER WIDTH=50%> DATA : $mom_date </th>"
  MOM_output_literal "</tr>"
  MOM_output_literal "</table>"
  MOM_output_literal "<CENTER><table WIDTH=700 BORDER=0>"
  MOM_output_literal "<tr ALIGN=CENTER VALIGN=CENTER>"
  MOM_output_literal "<tr>"
  MOM_output_literal "<th ALIGN=LEFT WIDTH=100%> NAZWA CZʌCI: \
                                          $mom_part_name </th>"
  MOM_output_literal "</tr>"
  MOM_output_literal "</table>"
  MOM_output_literal "<BR>"
}

#=============================================================================
proc MapToolType { TOOL_TYPE } {
#=============================================================================
  upvar $TOOL_TYPE tool_type
  global mom_tool_type
  global mom_tool_ug_type 

  if {[string match "Milling*" $mom_tool_type]} \
  {
    set tool_type "MILL"
  } elseif { [string match "Turning*" $mom_tool_type]} \
  {
    set tool_type "LATHE"
  } elseif { [string match "Drilling*" $mom_tool_type]} \
  {
    set tool_type "DRILL"
  } else \
  {
    if { [info exists mom_tool_ug_type ] } \
    {
        if { $mom_tool_ug_type == 1 } {
            set tool_type "MILL"
        } elseif { $mom_tool_ug_type == 2 } {
            set tool_type "DRILL"
        } elseif { $mom_tool_ug_type == 3 || \
                    $mom_tool_ug_type == 4 || \
                    $mom_tool_ug_type == 5 } {
            set tool_type "LATHE"
        } elseif { $mom_tool_ug_type == 15 } {
            # User Defined tools
            set tool_type "MILL"
        } else {
            set tool_type ""
        }
    } else \
    {
      set tool_type ""
    } 
  }
}

#==============================================================================
proc Open_Files {} {
#==============================================================================
    global mom_output_file_directory
    global mom_output_file_basename
    global mom_output_file_suffix
    global mom_sys_output_file_suffix

    set output_file_extn ""
    set output_file_type_extn ""

    if { [info exists mom_output_file_suffix ] } {
        if {[string length $mom_output_file_suffix] > 0} {
            set output_file_extn .${mom_output_file_suffix}
        }
    }

    set pre_ouput_file  "${mom_output_file_directory}${mom_output_file_basename}${output_file_extn}"

    MOM_close_output_file $pre_ouput_file

    if {[file exists $pre_ouput_file]} {
        MOM_remove_file $pre_ouput_file
    }

    if {[string length $output_file_extn] == 0} {
      if { [info exists mom_sys_output_file_suffix ] } {
          if {[string length $mom_sys_output_file_suffix] > 0} {
              set output_file_extn ".${mom_sys_output_file_suffix}"
          }
      }
    }

    set out_file "${mom_output_file_directory}${mom_output_file_basename}${output_file_extn}"

    MOM_close_output_file $out_file

    if {[file exists $out_file]} {
      MOM_remove_file $out_file
    }

    MOM_open_output_file $out_file

}
